==> bacula-docs-5.2.2.tar.bz2: bacula-docs-5.2.2/home-page/es/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">Bacula&reg; - La soluci&oacute;n de Backup Open Source Basada en Red 
   </td>
</tr>
<tr>
  <td class="content">
  <p>
  <b>Bacula</b> es un conjunto de programas Open Source, listos para la empresa, que permiten administrar los backups, restauraci&oacute;n y verificaci&oacute;n de datos en una red heterogenea. Bacula es relativamente f&aacute;cil de usar y eficiente, a la vez que ofrece muchas funcionalidades avanzadas para la administraci&oacute;n de los datos almacenados, lo cual facilita hallar y recuperar archivos perdidos o da&ntilde;ados. En t&eacute;rminos t&eacute;cnicos, Bacula es un <b>sistema de backups Open Source, orientado a la red y listo para la empresa</b>.
  </p>
  <p>De acuerdo a las estad&iacute;sticas de Source Forge (ranking y descargas), Bacula es por lejos el programa Open Source orientado a la empresa m&aacute;s popular.</p>

<table width="759" border="0" cellspacing="2" cellpadding="0">
   <tr>
    <td width="25"></td>
    <td><font size="5" color="#739ab9"><strong>Bacula.org y Bacula Systems: C&oacute;mo encontrar lo que necesita.</strong></font></td>
   </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
</table>

<p></p>
<table width="644" border="0" cellspacing="0" cellpadding="0" height="224">
 <tr height="215">
  <td align="center" valign="middle" width="331" height="215">
   <table width="237" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="158" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="276" border="0" cellspacing="0" cellpadding="0" height="137">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="210" height="137">
            <h4>Bacula.org es la home de la comunidad del proyecto bacula, para desarrolladores y contribuyentes. Aqu&iacute; puede encontrar el &uacute;ltimo lanzamiento de bacula junto con una completa documentaci&oacute;n.</h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>06 August 2010: <strong>Bacula 5.0.3</strong> lanzado.</p>
      <p></p>
      <p>Ver: <a href="http://www.bacula.org/en/?page=news">Noticias</a></p>
     </td>
    </tr>
   </table>
  </td>
  <td rowspan="2" width="25" height="229">
   <table class="cellcolor" width="3" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="320">
    <tr height="60">
     <td height="60"></td>
    </tr>
   </table>
  </td>
  <td align="center" valign="middle" width="210" height="215">
   <table width="288" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="276" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="264" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="271" height="137">
            <h4><a href="http://www.baculasystems.com">Bacula Systems</a> es la organizaci&oacute;n para el soporte comercial, servicios y training para Empresas que usan bacula. El sitio de Bacula Systems es <a href="http://www.baculasystems.com">www.baculasystems.com</a>
            </h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>September 2010: <strong><a href="http://www.baculasystems.com/index.php/products/enterprise-edition.html">
                     Bacula Enterprise Edition 4.0</a></strong> lanzado.</p>
      <p>Ver: <a href="http://www.baculasystems.com/index.php/company.html">Noticias de Bacula Systems</a>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr align="center" height="14">
  <td width="331" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr align="center" height="3">
     <td align="right" width="275" height="3"></td>
    </tr>
   </table>
  </td>
  <td width="210" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr height="3">
     <td width="209" height="3"></td>
    </tr>
   </table>
  </td>
 </tr>
</table>
<p></p>
La mayor parte del c&oacute;digo de <b>Bacula</b> est&aacute; liberado bajo la licencia <b>GPL</b> versi&oacute;n 2. Si desea m&aacute;s detalles, siga el enlace Licencia a su izquierda.
<br><br>
El enlace Documentaci&oacute;n permite el acceso a toda la documentaci&oacute;n de Bacula (HTML, PDF y TGZ) para ambos, el lanzamiento oficial y la que est&aacute; en desarrollo en el GIT de Source Forge. La versi&oacute;n en desarrollo de la documentaci&oacute;n generalmente est&aacute; m&aacute;s completa, aunque tambi&eacute;n puede documentar nuevas caracter&iacute;sticas y funcionalidades que no est&aacute;n en la versi&oacute;n lanzada. La <b>Gu&iacute;a para Desarrolladores</b> presenta informaci&oacute;n importante para los usuarios que quieran contribuir al proyecto Bacula.
<br><br>
Bacula se lanza en Source Forge <a href="http://sourceforge.net/projects/bacula"> http://sourceforge.net/projects/bacula </a>, desde donde puede bajar el software.
<br><br>
Tambi&eacute;n puede usar los enlaces a la izquierda para mayor informaci&oacute;n. En particular, el enlace Archivos Actuales lleva a la descarga de la versi&oacute;n actual, y Todas las Descargas, a un listado de todos los archivos lanzados en Source Forge.

  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>

==> bacula-docs-5.2.12.tar.bz2: bacula-docs-5.2.12/home-page/es/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">Bacula&reg; - La soluci&oacute;n de Backup Open Source Basada en Red 
   </td>
</tr>
<tr>
  <td class="content">
  <p>
  <b>Bacula</b> es un conjunto de programas Open Source, listos para la empresa, que permiten administrar los backups, restauraci&oacute;n y verificaci&oacute;n de datos en una red heterogenea. Bacula es relativamente f&aacute;cil de usar y eficiente, a la vez que ofrece muchas funcionalidades avanzadas para la administraci&oacute;n de los datos almacenados, lo cual facilita hallar y recuperar archivos perdidos o da&ntilde;ados. En t&eacute;rminos t&eacute;cnicos, Bacula es un <b>sistema de backups Open Source, orientado a la red y listo para la empresa</b>.
  </p>
  <p>De acuerdo a las estad&iacute;sticas de Source Forge (ranking y descargas), Bacula es por lejos el programa Open Source orientado a la empresa m&aacute;s popular.</p>

<table width="759" border="0" cellspacing="2" cellpadding="0">
   <tr>
    <td width="25"></td>
    <td><font size="5" color="#739ab9"><strong>Bacula.org y Bacula Systems: C&oacute;mo encontrar lo que necesita.</strong></font></td>
   </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
</table>

<p></p>
<table width="644" border="0" cellspacing="0" cellpadding="0" height="224">
 <tr height="215">
  <td align="center" valign="middle" width="331" height="215">
   <table width="237" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="158" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="276" border="0" cellspacing="0" cellpadding="0" height="137">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="210" height="137">
            <h4>Bacula.org es la home de la comunidad del proyecto bacula, para desarrolladores y contribuyentes. Aqu&iacute; puede encontrar el &uacute;ltimo lanzamiento de bacula junto con una completa documentaci&oacute;n.</h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>22 febrero 2012: <strong>Bacula 5.2.6</strong> lanzado.</p>
      <p></p>
      <p>Ver: <a href="http://www.bacula.org/en/?page=news">Noticias</a></p>
     </td>
    </tr>
   </table>
  </td>
  <td rowspan="2" width="25" height="229">
   <table class="cellcolor" width="3" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="320">
    <tr height="60">
     <td height="60"></td>
    </tr>
   </table>
  </td>
  <td align="center" valign="middle" width="210" height="215">
   <table width="288" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="276" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="264" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="271" height="137">
            <h4><a href="http://www.baculasystems.com">Bacula Systems</a> es la organizaci&oacute;n para el soporte comercial, servicios y training para Empresas que usan bacula. El sitio de Bacula Systems es <a href="http://www.baculasystems.com">www.baculasystems.com</a>
            </h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>September 2010: <strong><a href="http://www.baculasystems.com/index.php/products/enterprise-edition.html">
                     Bacula Enterprise Edition 4.0</a></strong> lanzado.</p>
      <p>Ver: <a href="http://www.baculasystems.com/index.php/company.html">Noticias de Bacula Systems</a>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr align="center" height="14">
  <td width="331" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr align="center" height="3">
     <td align="right" width="275" height="3"></td>
    </tr>
   </table>
  </td>
  <td width="210" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr height="3">
     <td width="209" height="3"></td>
    </tr>
   </table>
  </td>
 </tr>
</table>
<p></p>
La mayor parte del c&oacute;digo de <b>Bacula</b> est&aacute; liberado bajo la licencia <b>GPL</b> versi&oacute;n 2. Si desea m&aacute;s detalles, siga el enlace Licencia a su izquierda.
<br><br>
El enlace Documentaci&oacute;n permite el acceso a toda la documentaci&oacute;n de Bacula (HTML, PDF y TGZ) para ambos, el lanzamiento oficial y la que est&aacute; en desarrollo en el GIT de Source Forge. La versi&oacute;n en desarrollo de la documentaci&oacute;n generalmente est&aacute; m&aacute;s completa, aunque tambi&eacute;n puede documentar nuevas caracter&iacute;sticas y funcionalidades que no est&aacute;n en la versi&oacute;n lanzada. La <b>Gu&iacute;a para Desarrolladores</b> presenta informaci&oacute;n importante para los usuarios que quieran contribuir al proyecto Bacula.
<br><br>
Bacula se lanza en Source Forge <a href="http://sourceforge.net/projects/bacula"> http://sourceforge.net/projects/bacula </a>, desde donde puede bajar el software.
<br><br>
Tambi&eacute;n puede usar los enlaces a la izquierda para mayor informaci&oacute;n. En particular, el enlace Archivos Actuales lleva a la descarga de la versi&oacute;n actual, y Todas las Descargas, a un listado de todos los archivos lanzados en Source Forge.

  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>
